# Super duper waddle

[![pypi-image]][pypi-url]
[![license-image]][license-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![jupyter-book-image]][docs-url]

<!-- Links: -->
[pypi-image]: https://img.shields.io/pypi/v/super-duper-waddle
[license-image]: https://img.shields.io/github/license/entelecheia/super-duper-waddle
[license-url]: https://github.com/entelecheia/super-duper-waddle/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/entelecheia/super-duper-waddle?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/entelecheia/super-duper-waddle
[release-url]: https://github.com/entelecheia/super-duper-waddle/releases
[jupyter-book-image]: https://jupyterbook.org/en/stable/_images/badge.svg

[repo-url]: https://github.com/entelecheia/super-duper-waddle
[pypi-url]: https://pypi.org/project/super-duper-waddle
[docs-url]: https://entelecheia.github.io/super-duper-waddle
[changelog]: https://github.com/entelecheia/super-duper-waddle/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/entelecheia/super-duper-waddle/blob/main/CONTRIBUTING.md
<!-- Links: -->

Super duper waddle projet

- Documentation: [https://entelecheia.github.io/super-duper-waddle][docs-url]
- GitHub: [https://github.com/entelecheia/super-duper-waddle][repo-url]
- PyPI: [https://pypi.org/project/super-duper-waddle][pypi-url]

Super duper waddle pypi project

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [MIT License][license-url].
